@@ -4,7 +4,7 @@
 #' (output sorted in increasing order).
 #'
 #' @export eigensort
-#' @param x Symetric matrix whose spectral decomposition is to be computed.
+#' @param x Symetric matrix (sparse or dense) whose spectral decomposition is to be computed.
 #' @examples
 #' A <- matrix(1, ncol=2, nrow=2)
 #' dec <- eigensort(A)
@@ -12,5 +12,6 @@
 eigensort <- function(x) {
   dec <- eigen(x, symmetric = T)
   A <- dec$vectors
-  return(list(evalues = rev(dec$values), evectors = A[, ncol(A):1]))
+  return(list(evalues = rev(dec$values),
+              evectors = A[, ncol(A):1]))
 }
